==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/Performance/src/com/clustercontrol/performance/monitor/util/EjbConnectionManager.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.monitor.util;

import java.rmi.RemoteException;
import java.util.Hashtable;

import javax.ejb.CreateException;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.eclipse.jface.preference.IPreferenceStore;
import org.jnp.interfaces.NamingContext;
import org.jnp.interfaces.NamingContextFactory;

import com.clustercontrol.ClusterControlPlugin;
import com.clustercontrol.performanceMGR.monitor.ejb.session.MonitorPerfController;
import com.clustercontrol.performanceMGR.monitor.ejb.session.MonitorPerfControllerHome;
import com.clustercontrol.util.LoginManager;

/**
 * EJBȤΥͥ륯饹
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class EjbConnectionManager {
    public static final String KEY_EJB_URL = "ejbUrl";
    public static final String VALUE_EJB_URL = "jnp://localhost:1099";
    private static EjbConnectionManager m_instance = null;
    private NamingContext m_ctx = null;

    /**
     * Υ֥Ȥޤ
     * 
     * @return ConnectionManager ͥޥ͡
     */
    public static EjbConnectionManager getConnectionManager() {
        if (m_instance == null) {
            m_instance = new EjbConnectionManager();
        }
        return m_instance;
    }

    private EjbConnectionManager() {

    }

    /**
     * ProcessControllerޤ
     * 
     * @return MonitorController
     */
    public synchronized MonitorPerfController getMonitorPerfController() {  	
    	try {
            m_ctx = getContext();
        } catch (NamingException e) {
            return null;
        }
    	
        MonitorPerfControllerHome home;
        try {
            home = (MonitorPerfControllerHome) m_ctx
                    .lookup(MonitorPerfControllerHome.JNDI_NAME);
            return home.create();
        } catch (NamingException e) {
        	e.printStackTrace();
        } catch (RemoteException e) {
        	e.printStackTrace();
        } catch (CreateException e) {
        	e.printStackTrace();
        }
        m_ctx = null;
        return null;
    }
    
    private NamingContext getContext() throws NamingException {
    	NamingContext namingContext = LoginManager.getContextManager().getNamingContext();
        
        return namingContext;
    }

    /**
     * ³URLޤ
     * 
     * @return String ³URL
     */
    private String getUrl() {
    	String url = null;
    	
        //꥽ȥ³URL
    	if(ClusterControlPlugin.getDefault() != null){
    		IPreferenceStore store = ClusterControlPlugin.getDefault().getPreferenceStore();
            url = store.getString(KEY_EJB_URL);
            if (url.compareTo("") == 0) {
                url = VALUE_EJB_URL;
            }
    	}
    	
        return url;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/Performance/src/com/clustercontrol/performance/monitor/util/EjbConnectionManager.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.monitor.util;

import java.rmi.RemoteException;
import java.util.Hashtable;

import javax.ejb.CreateException;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.eclipse.jface.preference.IPreferenceStore;
import org.jnp.interfaces.NamingContext;
import org.jnp.interfaces.NamingContextFactory;

import com.clustercontrol.ClusterControlPlugin;
import com.clustercontrol.performanceMGR.monitor.ejb.session.MonitorPerfController;
import com.clustercontrol.performanceMGR.monitor.ejb.session.MonitorPerfControllerHome;
import com.clustercontrol.util.LoginManager;

/**
 * EJBとのコネクションを管理するクラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class EjbConnectionManager {
    public static final String KEY_EJB_URL = "ejbUrl";
    public static final String VALUE_EJB_URL = "jnp://localhost:1099";
    private static EjbConnectionManager m_instance = null;
    private NamingContext m_ctx = null;

    /**
     * このオブジェクトを取得します。
     * 
     * @return ConnectionManager コネクションマネージャ
     */
    public static EjbConnectionManager getConnectionManager() {
        if (m_instance == null) {
            m_instance = new EjbConnectionManager();
        }
        return m_instance;
    }

    private EjbConnectionManager() {

    }

    /**
     * ProcessControllerを取得します。
     * 
     * @return MonitorController
     */
    public synchronized MonitorPerfController getMonitorPerfController() {  	
    	try {
            m_ctx = getContext();
        } catch (NamingException e) {
            return null;
        }
    	
        MonitorPerfControllerHome home;
        try {
            home = (MonitorPerfControllerHome) m_ctx
                    .lookup(MonitorPerfControllerHome.JNDI_NAME);
            return home.create();
        } catch (NamingException e) {
        	e.printStackTrace();
        } catch (RemoteException e) {
        	e.printStackTrace();
        } catch (CreateException e) {
        	e.printStackTrace();
        }
        m_ctx = null;
        return null;
    }
    
    private NamingContext getContext() throws NamingException {
    	NamingContext namingContext = LoginManager.getContextManager().getNamingContext();
        
        return namingContext;
    }

    /**
     * 接続先URLを取得します。
     * 
     * @return String 接続先URL
     */
    private String getUrl() {
    	String url = null;
    	
        //リソースストアから接続先URLを取得
    	if(ClusterControlPlugin.getDefault() != null){
    		IPreferenceStore store = ClusterControlPlugin.getDefault().getPreferenceStore();
            url = store.getString(KEY_EJB_URL);
            if (url.compareTo("") == 0) {
                url = VALUE_EJB_URL;
            }
    	}
    	
        return url;
    }
}
